@@ -4,7 +4,7 @@
 import tornado.web
 from tornado.util import ObjectDict
 
-from tornado.web import _UIModuleNamespace,StaticFileHandler
+from tornado.web import _UIModuleNamespace, StaticFileHandler
 from tornado.escape import xhtml_escape, url_escape
 
 import functools
@@ -13,7 +13,6 @@ import re
 
 from time import time
 
-
 from tornadoez.mail import MailClient2
 
 
@@ -117,10 +116,10 @@ def model(method):
 
         self.debug = self.handler.debug
 
-        if hasattr(self.handler,"dbs"):
+        if hasattr(self.handler, "dbs"):
             self.dbs = self.handler.dbs
 
-        if hasattr(self.handler,"cache_db"):
+        if hasattr(self.handler, "cache_db"):
             self.cache_db = self.handler.cache_db
 
         return method(self, *args, **kwargs)
@@ -205,173 +204,175 @@ def detect_ie(method):
 
 
 class RequestHandler(tornado.web.RequestHandler):
-    # def __init__(self, application, request, **kwargs):
-    #     '''
-    #     a lot of code copy from tornado,because we must make sure self.initialize execute at last
-    #     :param application:
-    #     :param request:
-    #     :param kwargs:
-    #     :return:
-    #     '''
-    #
-    #     super(RequestHandler, self).__init__(application,request,**kwargs)
-    #
-    #     self.application = application
-    #     self.request = request
-    #     self._headers_written = False
-    #     self._finished = False
-    #     self._auto_finish = True
-    #     self._transforms = None  # will be set in _execute
-    #     self._prepared_future = None
-    #     self.path_args = None
-    #     self.path_kwargs = None
-    #     self.ui = ObjectDict((n, self._ui_method(m)) for n, m in
-    #                          application.ui_methods.items())
-    #
-    #
-    #
-    #     # ez-hack
-    #
-    #     # self.debug = self.application.settings.get('debug', False)
-    #     # self.css_debug = self.application.settings.get('css_debug', False)
-    #     # self.js_debug = self.application.settings.get('js_debug', False)
-    #     #
-    #     #
-    #     # self.cdn = self.application.settings.get('cdn', '')
-    #     # self.browser_type = self.application.settings.get('browser_default_type', 'mobile')
-    #     # self.db = self.application.settings.get('db', NotImplemented)
-    #     # self.acct_db = self.application.settings.get('acct_db', NotImplemented)
-    #     # self.auth_callback = self.application.settings.get('auth_callback', NotImplemented)
-    #     #
-    #     # self.message_queue = self.application.settings.get('message_queue', NotImplemented)
-    #     # self.queue_config = self.application.settings.get('queue_config', NotImplemented)
-    #     #
-    #     # self.cache_db = self.application.settings.get('cache_db', NotImplemented)
-    #     # self.cache_config = self.application.settings.get('cache_config', NotImplemented)
-    #     #
-    #     # self.files_db = self.application.settings.get('files_db', NotImplemented)
-    #     # self.dbs = self.application.settings.get('dbs', NotImplemented)
-    #     #
-    #     # self.db_refer = self.application.settings.get('db_refer', NotImplemented)
-    #     #
-    #     # self.session = self.application.settings.get('session', NotImplemented)
-    #     # self.statsd = self.application.settings.get('statsd', NotImplemented)
-    #     #
-    #     # self.locale_callback = self.application.settings.get('locale_callback', NotImplemented)
-    #     #
-    #     # self.hacking_ie = None
-    #     #
-    #     # # maybe not a good design
-    #     # # self.template_urls = self.application.settings.get('template_urls', NotImplemented)
-    #     # # self.template_keys = self.application.settings.get('template_keys', NotImplemented)
-    #     #
-    #     # self.api_messages = self.application.settings.get('api_messages', {})
-    #     #
-    #     # self.project_version = self.application.settings.get('version', None)
-    #     # self.project_name = self.application.settings.get('project', {}).get('name','')
-    #     # self.project_desc = self.application.settings.get('project', {}).get('desc','')
-    #     # self.project_keywords = self.application.settings.get('project', {}).get('keywords','')
-    #     #
-    #     # self.css_version = self.application.settings.get('css_version', str(int(time())))
-    #     # self.js_version = self.application.settings.get('js_version', str(int(time())))
-    #     #
-    #     #
-    #     # self.favicon = self.application.settings.get('favicon', "/static/favicon.ico")
-    #     # self.copyright_text = self.application.settings.get('copyright_text', '')
-    #     # self.copyright = self.application.settings.get('copyright', '')
-    #     # self.author = self.application.settings.get('author', '')
-    #     #
-    #     #
-    #     # #mail client
-    #     # _smtp_config = self.application.settings.get('smtp')
-    #     #
-    #     # if _smtp_config:
-    #     #     self.smtp = MailClient2(_smtp_config)
-    #     # else:
-    #     #     self.smtp = None
-    #
-    #
-    #
-    #
-    #
-    #     # UIModules are available as both `modules` and `_tt_modules` in the
-    #     # template namespace.  Historically only `modules` was available
-    #     # but could be clobbered by user additions to the namespace.
-    #     # The template {% module %} directive looks in `_tt_modules` to avoid
-    #     # possible conflicts.
-    #     self.ui["_tt_modules"] = _UIModuleNamespace(self,
-    #                                                 application.ui_modules)
-    #     self.ui["modules"] = self.ui["_tt_modules"]
-    #     self.clear()
-    #     self.request.connection.set_close_callback(self.on_connection_close)
-    #     self.initialize(**kwargs)
-    #     pass
+    def __init__(self, application, request, **kwargs):
+        '''
+        a lot of code copy from tornado,because we must make sure self.initialize execute at last
+        :param application:
+        :param request:
+        :param kwargs:
+        :return:
+        '''
+
+        super(RequestHandler, self).__init__(application, request, **kwargs)
+
+        self.application = application
+        self.request = request
+        self._headers_written = False
+        self._finished = False
+        self._auto_finish = True
+        self._transforms = None  # will be set in _execute
+        self._prepared_future = None
+        self.path_args = None
+        self.path_kwargs = None
+        self.ui = ObjectDict((n, self._ui_method(m)) for n, m in
+                             application.ui_methods.items())
 
 
-    def initialize(self):
-        self.debug = None
-        self.css_debug = None
-        self.js_debug = None
 
+        # ez-hack
 
-        self.cdn = None
-        self.browser_type = None
+        self.debug = self.application.settings.get('debug', False)
+        self.css_debug = self.application.settings.get('css_debug', False)
+        self.js_debug = self.application.settings.get('js_debug', False)
+
+        self.cdn = self.application.settings.get('cdn', '')
+        self.browser_type = self.application.settings.get('browser_default_type', 'mobile')
+        # self.db = self.application.settings.get('db', NotImplemented)
         self.db = None
+        # self.acct_db = self.application.settings.get('acct_db', NotImplemented)
         self.acct_db = None
-        self.auth_callback = None
 
-        self.message_queue = None
-        self.queue_config = None
+        self.auth_callback = self.application.settings.get('auth_callback', NotImplemented)
 
-        self.cache_db = None
-        self.cache_config = None
+        self.message_queue = self.application.settings.get('message_queue', NotImplemented)
+        self.queue_config = self.application.settings.get('queue_config', NotImplemented)
 
-        self.files_db = None
-        self.dbs = None
+        self.cache_db = self.application.settings.get('cache_db', NotImplemented)
+        self.cache_config = self.application.settings.get('cache_config', NotImplemented)
 
+        self.files_db = self.application.settings.get('files_db', NotImplemented)
+        self.dbs = self.application.settings.get('dbs', NotImplemented)
+
+        # self.db_refer = self.application.settings.get('db_refer', NotImplemented)
         self.db_refer = None
 
-        self.session = None
-        self.statsd = None
+        self.session = self.application.settings.get('session', NotImplemented)
+        self.statsd = self.application.settings.get('statsd', NotImplemented)
 
-        self.locale_callback = None
+        self.locale_callback = self.application.settings.get('locale_callback', NotImplemented)
 
         self.hacking_ie = None
 
         # maybe not a good design
-        # self.template_urls = None
-        # self.template_keys = None
+        # self.template_urls = self.application.settings.get('template_urls', NotImplemented)
+        # self.template_keys = self.application.settings.get('template_keys', NotImplemented)
 
-        self.api_messages = None
+        self.api_messages = self.application.settings.get('api_messages', {})
 
-        self.project_version = None
-        self.project_name = None
-        self.project_desc = None
-        self.project_keywords = None
+        self.project_version = self.application.settings.get('version', None)
+        self.project_name = self.application.settings.get('project', {}).get('name', '')
+        self.project_desc = self.application.settings.get('project', {}).get('desc', '')
+        self.project_keywords = self.application.settings.get('project', {}).get('keywords', '')
 
-        self.css_version = None
-        self.js_version = None
+        self.css_version = self.application.settings.get('css_version', str(int(time())))
+        self.js_version = self.application.settings.get('js_version', str(int(time())))
+
+        self.favicon = self.application.settings.get('favicon', "/static/favicon.ico")
+        self.copyright_text = self.application.settings.get('copyright_text', '')
+        self.copyright = self.application.settings.get('copyright', '')
+        self.author = self.application.settings.get('author', '')
 
 
-        self.favicon = None
-        self.copyright_text = None
-        self.copyright = None
-        self.author = None
-
-
-        #mail client
-        _smtp_config = None
+        # mail client
+        _smtp_config = self.application.settings.get('smtp')
 
         if _smtp_config:
-            self.smtp = None
+            self.smtp = MailClient2(_smtp_config)
         else:
             self.smtp = None
 
-        # ez-hack-end
 
+
+
+
+        # UIModules are available as both `modules` and `_tt_modules` in the
+        # template namespace.  Historically only `modules` was available
+        # but could be clobbered by user additions to the namespace.
+        # The template {% module %} directive looks in `_tt_modules` to avoid
+        # possible conflicts.
+        self.ui["_tt_modules"] = _UIModuleNamespace(self,
+                                                    application.ui_modules)
+        self.ui["modules"] = self.ui["_tt_modules"]
+        self.clear()
+        self.request.connection.set_close_callback(self.on_connection_close)
+        self.initialize(**kwargs)
         pass
 
 
+    # def initialize(self):
+    # self.debug = None
+    #     self.css_debug = None
+    #     self.js_debug = None
+    #
+    #
+    #     self.cdn = None
+    #     self.browser_type = None
+    #     self.db = None
+    #     self.acct_db = None
+    #     self.auth_callback = None
+    #
+    #     self.message_queue = None
+    #     self.queue_config = None
+    #
+    #     self.cache_db = None
+    #     self.cache_config = None
+    #
+    #     self.files_db = None
+    #     self.dbs = None
+    #
+    #     self.db_refer = None
+    #
+    #     self.session = None
+    #     self.statsd = None
+    #
+    #     self.locale_callback = None
+    #
+    #     self.hacking_ie = None
+    #
+    #     # maybe not a good design
+    #     # self.template_urls = None
+    #     # self.template_keys = None
+    #
+    #     self.api_messages = None
+    #
+    #     self.project_version = None
+    #     self.project_name = None
+    #     self.project_desc = None
+    #     self.project_keywords = None
+    #
+    #     self.css_version = None
+    #     self.js_version = None
+    #
+    #
+    #     self.favicon = None
+    #     self.copyright_text = None
+    #     self.copyright = None
+    #     self.author = None
+    #
+    #
+    #     #mail client
+    #     _smtp_config = None
+    #
+    #     if _smtp_config:
+    #         self.smtp = None
+    #     else:
+    #         self.smtp = None
+    #
+    #     # ez-hack-end
+    #
+    #     pass
+
+
     def get_current_user(self):
         '''
         use user custom auth function if set.
@@ -410,15 +411,15 @@ class RequestHandler(tornado.web.RequestHandler):
             'debug': int(self.debug),
             'project_version': self.project_version,
             'project_name': self.project_name,
-            'project_desc':self.project_desc,
-            'project_keywords':self.project_keywords,
+            'project_desc': self.project_desc,
+            'project_keywords': self.project_keywords,
             'author': self.author,
-            'copyright':self.copyright,
-            'copyright_text':self.copyright_text,
-            'js_version':self.js_version,
-            'css_version':self.css_version,
-            'js_debug':self.js_debug,
-            'css_debug':self.css_debug
+            'copyright': self.copyright,
+            'copyright_text': self.copyright_text,
+            'js_version': self.js_version,
+            'css_version': self.css_version,
+            'js_debug': self.js_debug,
+            'css_debug': self.css_debug
         })
 
         return namespace
@@ -469,7 +470,6 @@ class RequestHandler(tornado.web.RequestHandler):
         pass
 
 
-
     def post_redirect(self, url, msg, breadcrumbs=[], recommend=[], *args, **kwargs):
 
         """
